# avocadopy

This is a package of Python scripts which are usefull for medical statistics.  


## Usage:

```
from avocadopy import utils

utils.unique([1, 2, 2, 3])

utils.shell_run("ls *.txt")

```
